@@ -22,7 +22,7 @@ node *grbg;
 long tipy;
 
 double **timesseen, **tmseen2, **times2 ;
-double *timesseen_changes, *tchange2;
+double *tchange2;
 double trweight, ntrees, mlfrac;
 
 /* prototypes */
@@ -941,8 +941,8 @@ void rehash()
     memcpy(s, grouping[old_index], setsz * sizeof(group_type));
     ss = 0.0;
     for (j = 0; j < setsz; j++)
-      ss += s[j] /* pow(2, SETBITS*j)*/;
-    temp = ss * smult;
+      ss += s[j] * smult; /* pow(2, SETBITS*j)*/;
+    temp = ss;
     new_index = (long)(new_maxgrp * (temp - floor(temp)));
     done = false;
     while (!done) {
@@ -960,9 +960,6 @@ void rehash()
 
         lengths2[new_index] = lengths[old_index];
 
-        tchange2[new_index] = timesseen_changes[old_index];
-
-
         free(grouping[old_index]);
         free(timesseen[old_index]);
         free(order[i]);
@@ -984,7 +981,6 @@ void rehash()
   free(timesseen);
   free(grouping);
   free(order);
-  free(timesseen_changes);
 
   free(s);
 
@@ -992,7 +988,6 @@ void rehash()
   grouping = grping2;
   lengths = lengths2;
   order = order2;
-  timesseen_changes = tchange2;
 
   maxgrp = new_maxgrp;
 
@@ -1030,13 +1025,18 @@ void enternodeset(node* r)
   while (!done) {
     if (grouping[i - 1]) {        /* ... i.e. if group is absent, or  */
       same = false;               /* (will be false if timesseen = 0) */
-      if (!(timesseen[i-1] == 0)) {  /* ... if timesseen = 0 */
+      if (!(timesseen[i-1] == 0)) {
         same = true;
         for (j = 0; j < setsz; j++) {
           if (s[j] != grouping[i - 1][j])
             same = false;
         }
       }
+      else {                       /* if group is present but timessen = 0 */
+        for (j = 0; j < setsz; j++)   /* replace by correct group */
+          grouping[i - 1][j] = s[j];
+        *timesseen[i-1] = 1;
+      }
     }
     if (grouping[i - 1] && same) {  /* if it is there, increment timesseen */
       *timesseen[i - 1] += times;
@@ -1053,9 +1053,9 @@ void enternodeset(node* r)
       done = true;
       lengths[i - 1] = nodep[r->index -1]->v;
     } else {  /* otherwise look to put it in next slot ... */
-      i++;
-      if (i > maxgrp) i -= maxgrp;
-    }
+        i++;
+        if (i > maxgrp) i -= maxgrp;
+      }
     if (!done && i == start) {  /* if no place to put it, expand hash table */
 
       rehash();
@@ -1335,7 +1335,7 @@ void store_pattern (pattern_elm ***pattern_array, int trees_in_file)
   /* First, find out how many groups exist in the given tree. */
   for (i = 0 ; i < maxgrp ; i++)
     if ((grouping[i] != NULL) &&
-       (*timesseen[i] > timesseen_changes[i]))
+		  (*timesseen[i] > 0))
       /* If this is group exists and is present in the current tree, */
       total_groups++ ;
 
@@ -1357,13 +1357,12 @@ void store_pattern (pattern_elm ***pattern_array, int trees_in_file)
      appropriately. */
   for (i = 0 ; i < maxgrp ; i++)
     if (grouping[i] != NULL) {
-      if (*timesseen[i] > timesseen_changes[i]) {
+      if (*timesseen[i] > 0) {
         for (k = 0 ; k < setsz ; k++)
           pattern_array[k][trees_in_file]->apattern[j] = grouping[i][k] ;  
         pattern_array[0][trees_in_file]->length[j] = lengths[i];
         j++ ;
 
-        timesseen_changes[i] = *timesseen[i] ;
           /* 
              EWFIX.BUG.756
 
@@ -1380,6 +1379,7 @@ void store_pattern (pattern_elm ***pattern_array, int trees_in_file)
              consense.
              
           */
+      *timesseen[i] = 0;
       }
     }
   *pattern_array[0][trees_in_file]->patternsize = total_groups;
@@ -1434,10 +1434,6 @@ void read_groups (pattern_elm ****pattern_array,
   grouping  = (group_type **)  Malloc(maxgrp*sizeof(group_type *));
   lengths  = (double *)  Malloc(maxgrp*sizeof(double));
 
-  timesseen_changes = (double*)Malloc(maxgrp*sizeof(double));
-  for (i = 0; i < maxgrp; i++)
-    timesseen_changes[i] = 0.0;
-
   for (i = 0; i < maxgrp; i++)
     grouping[i] = NULL;
 
@@ -1525,10 +1521,15 @@ void read_groups (pattern_elm ****pattern_array,
            current pattern as an element of it's trees array. */
       store_pattern ((*pattern_array), trees_read) ;
       trees_read++ ;
+      for (i = 0; i < maxgrp; i++)
+        if (grouping[i] != NULL) {
+          *timesseen[i] = 0;
+        }
     }
   }
 } /* read_groups */
 
+
 void clean_up_final()
 {
     long i;
@@ -1548,7 +1549,6 @@ void clean_up_final()
     free(nayme);
     free(order);
     free(timesseen);
-    free(timesseen_changes);
     free(fullset);
     free(lengths);
 
